// src/index.tsx
import HighlightJS from "highlight.js";
import {
  createMemo,
  mergeProps,
  splitProps
} from "solid-js";

// src/utils/index.ts
function escapeHtml(value) {
  return value.replace(/&/g, "&amp;").replace(/</g, "&lt;").replace(/>/g, "&gt;").replace(/"/g, "&quot;").replace(/'/g, "&#x27;");
}

// src/index.tsx
var Highlight = (_props) => {
  const props = mergeProps(
    { autoDetect: true, ignoreIllegals: true, language: "" },
    _props
  );
  const [, rest] = splitProps(props, [
    "language",
    "autoDetect",
    "ignoreIllegals",
    "children",
    "class",
    "innerHTML"
  ]);
  const cannotDetectLanguage = !props.autoDetect && !props.language && props.children && !HighlightJS.getLanguage(props.children.toString());
  const className = cannotDetectLanguage ? "" : `hljs ${props.language}`;
  const getHighlightedCode = createMemo(() => {
    const childrenString = props.children?.toString();
    if (!childrenString) {
      return "";
    }
    if (cannotDetectLanguage) {
      console.warn(
        `The language "${props.language}" you specified could not be found.`
      );
      return escapeHtml(childrenString);
    }
    if (props.autoDetect) {
      const result = HighlightJS.highlightAuto(childrenString);
      return result.value;
    } else {
      const result = HighlightJS.highlight(childrenString, {
        language: props.language,
        ignoreIllegals: props.ignoreIllegals
      });
      return result.value;
    }
  });
  return <pre><code
    class={`${className} ${props.class || ""}`}
    innerHTML={getHighlightedCode()}
    {...rest}
  /></pre>;
};
export {
  Highlight
};
